@@ -76,11 +76,14 @@ void main_loop(void)
 {
     fd_set rset;
     int nr;
+
+    if(opt.quiet && nr_songs == 0)
+	return;
     
     maxfd=getdtablesize();
     draw_screen();
     set_voice_detail(1); /* Start with highest detail */
-
+    
     set_status(STATUS_READY);
     selecting=quit=0;
     cur_filenr=first_voice=0;
@@ -155,17 +158,16 @@ void load_next_module(void)
     clear_screen();
     clear_all_info();
 
-    info("\n\n");
-
     /* Make sure sequencer is clean */
     cleanup_sound();
     init_sound();
 
+    /* Try loading a module until we succeed or abort */
     while(!quit) {
 	get_module(fileidx_to_seqidx(cur_filenr));	
 	print_filename(fileidx_to_seqidx(cur_filenr));
 	tmp=load_module();
-	chdir(workdir); /* Restore current directory */
+	chdir(workdir); /* Restore current directory after load_module() */
 	if(!tmp) {
 	    if(quit != QUIT_SIGNAL) {
 		print_status("Loading failed");
@@ -202,7 +204,7 @@ void load_next_module(void)
 	error("Fork failed.\n");
 	break;
 	
-      case 0:  /* Child */
+      case 0:  /* Child - player */
 	play_module();
 	cleanup_sound();
 	exit(0);
@@ -595,7 +597,7 @@ int should_autoselect_next(void)
 	return 1;
     
     if(opt.play_list) {
-	if(fileidx_to_seqidx(cur_filenr)==nr_songs-1) {
+	if(fileidx_to_seqidx(cur_filenr) == nr_songs-1) {
 	    return 0;
 	}
     }
@@ -732,8 +734,16 @@ void read_syncedmessage(void)
 			load_next_module();
 		    }
 		    else {
-			pending_restart=MESSAGE_STOP;
-			handle_restart(42);
+			/* Exit if we are in batch-mode */
+			if(opt.quiet) {
+			    mess.type=MESSAGE_EXIT;
+			    send_to_player(&mess);
+			    quit=QUIT_QUIT;
+			}
+			else {
+			    pending_restart=MESSAGE_STOP;
+			    handle_restart(42);
+			}
 		    }
 		}
 	    }
