@@ -169,6 +169,8 @@ void check_tick0_efx(int v)
 	if(a) {
 	    V[v].toneporta_speed=a*4;
 	}
+	if(M.format == MODFORMAT_S3M)
+	    do_toneportamento(v);
 	/* Fall through */
       case EFX_PORTANOTEVOLSLIDE:
 	if(cur_event->note && cur_event->note != NOTE_OFF) {
