@@ -217,9 +217,9 @@ int load_module(void)
 	unlink(buf);
     }
 
-    info("Tracks stored: %d/%d.\n", M.nr_tracks, M.nr_voices*M.nr_patterns);
+    info("\nTracks stored: %d/%d.\n", M.nr_tracks, M.nr_voices*M.nr_patterns);
 
-    return tmp;      /* Return status from load_? */
+    return tmp;      /* Return status from load_xxx */
 }
 
 
