@@ -50,6 +50,9 @@ void play_tick(void)
 {
     int i;
 
+    if(_seqbufptr)
+	error("Buffer not flushed on entry to play_tick()\n");
+
     tick++;
     if(tick >= speed) { /* Next line/position ... */
 	tick=0;
@@ -132,6 +135,9 @@ void play_tick(void)
 	return; /* No printing or processing when song is done */
     }
     
+    SEQ_WAIT_TIME((int)(mod_time+0.5));
+    i=_seqbufptr;
+    
     if(!tick && !efx.pattern_delay) {
 	if(advance_songpos)
 	    advance_songpos=0;
@@ -144,10 +150,12 @@ void play_tick(void)
 	}
 	send_line();
     }
+
     process_line(efx.pattern_delay ? 1 : 0);
     
     mod_time+=tick_time;
-    SEQ_WAIT_TIME((int)(mod_time+0.5));
+    if(_seqbufptr == i) /* Remove WAIT-event if possible */
+	_seqbufptr=0;
 }
 
 
@@ -336,7 +344,9 @@ void init_sequencer_voices(void)
 {
     int i;
     
-    ioctl(seqfd, SNDCTL_SEQ_RESET, 0);   /* Kill events */
+    ioctl(seqfd, SNDCTL_SEQ_RESET, 0);     /* Kill events */
+    i=750;
+    ioctl(seqfd, SNDCTL_SEQ_TRESHOLD, &i); /* Set threshold */
     _seqbufptr=0;
     GUS_NUMVOICES(gus_dev, M.nr_voices);
     SEQ_VOLUME_MODE(gus_dev, VOL_METHOD_LINEAR);
